@@ -16,7 +16,7 @@ import (
 )
 
 type ResourceTypes interface {
-	All() ([]ResourceType, error)
+	All(ignoreCachedResTypes bool) ([]ResourceType, error)
 	Find(Resource) (ResourceType, error)
 	CanIgnoreFailingGroupVersion(schema.GroupVersion) bool
 }
@@ -45,7 +45,11 @@ func NewResourceTypesImpl(coreClient kubernetes.Interface, opts ResourceTypesImp
 	return &ResourceTypesImpl{coreClient: coreClient, opts: opts}
 }
 
-func (g *ResourceTypesImpl) All() ([]ResourceType, error) {
+func (g *ResourceTypesImpl) All(ignoreCachedResTypes bool) ([]ResourceType, error) {
+	if ignoreCachedResTypes {
+		// TODO Update cache while doing a fresh fetch
+		return g.all()
+	}
 	return g.memoizedAll()
 }
 
